@@ -23,27 +23,17 @@ class Storage(driver.Base):
         self._secret_key = config.jss_secretkey
         self._bucket = config.jss_bucket
         self._domain = config.jss_domain
-        self._rootpath = path if path[0] != '/' else path[1:]
         logger.info("==========================>access_key:%s" % config.jss_accesskey)
         logger.info("==========================>jss_secretkey:%s" % config.jss_secretkey)
         logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
         logger.info("==========================>jss_domain:%s" % config.jss_domain)
-        logger.info("==========================>rootpath:%s" % self._rootpath)
         
         self._jss = JssClient(self._access_key, self._secret_key, self._domain, None)
         
     def _init_path(self, path=None):
-        res = self._rootpath
-        if not path:
-            res = self._rootpath
-        else:
-            if path.startswith(self._rootpath):
-                res = path
-            else:
-                res = os.path.join(self._rootpath, path)
-            
-        return res.replace("/", ".")
-
+        if  path:
+            return path.replace("/", ".")
+       
     def content_redirect_url(self, path):
         logger.info("content_redirect_url path:%s" % path)
         path1 = self._init_path(path)
